@@ -1,6 +1,6 @@
 package Data::SearchEngine::ElasticSearch;
 {
-  $Data::SearchEngine::ElasticSearch::VERSION = '0.17';
+  $Data::SearchEngine::ElasticSearch::VERSION = '0.18';
 }
 use Moose;
 
@@ -50,6 +50,9 @@ has 'transport' => (
 );
 
 
+sub engine { (shift)->_es }
+
+
 sub add {
     my ($self, $items, $options) = @_;
 
@@ -243,6 +246,7 @@ sub _doc_to_item {
     $values->{_version} = $doc->{_version};
     return Data::SearchEngine::Item->new(
         id      => $doc->{_id},
+        score   => $doc->{_score},
         values  => $values,
     );
 }
@@ -273,7 +277,7 @@ Data::SearchEngine::ElasticSearch - ElasticSearch support for Data::SearchEngine
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -398,6 +402,10 @@ The transport to use.  Refer to L<ElasticSearch> for more information.
 
 =head1 METHODS
 
+=head2 engine
+
+Returns the underlying search engine handle
+
 =head2 add ([ $items ])
 
 Add items to the index.  Keep in mind that the L<Data::SearchEngine::Item>
